django-onpay
============

.. image:: https://badge.fury.io/py/django-onpay.png
    :target: http://badge.fury.io/py/django-onpay

.. image:: https://travis-ci.org/marazmiki/django-onpay.png?branch=master
        :target: https://travis-ci.org/marazmiki/django-onpay

.. image:: https://coveralls.io/repos/marazmiki/django-onpay/badge.png?branch=master
  :target: https://coveralls.io/r/marazmiki/django-onpay?branch=master

.. image:: https://pypip.in/d/django-onpay/badge.png
        :target: https://pypi.python.org/pypi/django-onpay

.. image:: https://pypip.in/d/django-onpay/badge.png
    :target: https://pypi.python.org/pypi/django-onpay
    :alt: Latest version on PyPI

.. image:: https://pypip.in/wheel/django-onpay/badge.svg
    :target: https://pypi.python.org/pypi/django-onpay/
    :alt: Wheel Status


